#
# spec file for package sshguard
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sshguard
Version:        1.6.3
Release:        2.5
Summary:        Protect hosts from brute force attacks against ssh
License:        ISC
Group:          Productivity/Networking/Security
Url:            http://www.sshguard.net
Source0:        http://sourceforge.net/projects/%{name}/files/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:        sshguard.sysconfig
Source2:        sshguard.service
Source3:        sshguard.init
Source4:        sshguard.whitelist
# PATCH-FIX-UPSTREAM sshguard-gcc5.patch
Patch0:         sshguard-gcc5.patch
Requires:       openssh
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):  %fillup_prereq
%if 0%{?suse_version} > 1140
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%define has_systemd 1
%else
Requires(pre):  %fillup_prereq
%endif

%description
Sshguard protects networked hosts from brute force attacks
against ssh servers. It detects such attacks and blocks the
attacker's address with a firewall rule.

%prep
%setup -q
%patch0 -p1

%build
%configure \
  --with-firewall=iptables \
  --with-iptables=%{_sbindir}/iptables
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
install -D -m0644 %{SOURCE1} %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.sshguard
%if 0%{?has_systemd}
ln -sf service %{buildroot}/%{_sbindir}/rc%{name}
install -D -m0644 %{SOURCE2} %{buildroot}%{_unitdir}/sshguard.service
%else
install -D -m0744 %{SOURCE3} %{buildroot}%{_sysconfdir}/init.d/sshguard
ln -s ../..%{_sysconfdir}/init.d/sshguard %{buildroot}%{_sbindir}/rcsshguard
%endif
install -d -m0755 %{buildroot}%{_sysconfdir}/%{name}
install -D -m0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}/whitelist
install -d -m0755 %{buildroot}%{_localstatedir}/lib/%{name}/db
%fillup_and_insserv

%pre
%if 0%{?has_systemd}
%service_add_pre %{name}.service
%endif

%post
%if 0%{?has_systemd}
%fillup_only sshguard
%service_add_post sshguard.service
%else
%fillup_and_insserv sshguard
%endif

%preun
%if 0%{?has_systemd}
%service_del_preun sshguard.service
%else
%stop_on_removal sshguard
%endif

%postun
%if 0%{?has_systemd}
%service_del_postun sshguard.service
%else
%restart_on_update sshguard
%insserv_cleanup
%endif

%files
%defattr(-,root,root,-)
%doc ChangeLog README.rst COPYING examples/ 
%{_sbindir}/*
%doc %{_mandir}/man8/%{name}*
%{_localstatedir}/adm/fillup-templates/sysconfig.sshguard
%if 0%{?has_systemd}
%{_unitdir}/sshguard.service
%else
%config %{_sysconfdir}/init.d/sshguard
%endif
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/whitelist
%dir %{_localstatedir}/lib/%{name}
%attr(755,root,root) %{_localstatedir}/lib/%{name}/db

%changelog
* Fri Feb 19 2016 joop.boonen@opensuse.org
- Added a corrected attack treshold value (40 default)
* Thu Feb 18 2016 eshmarnev@suse.com
- Build version 1.6.3
  - Disable blacklisting by default
  - Implement logging as wrappers around syslog(2)
  - Improve log and error messages
  - Match sendmail authentication failures
  - Remove PID file option
  - Remove SIGTSTP and SIGCONT handler
  - Remove reverse mapping attack signature
  - Remove safe_fgets() and exit on interrupt
  - Terminate state entries for hosts blocked with pf
  - Update and shorten command-line usage
  - Use 'configure' to set feature-test macros
- Updated patch file for new version of sshguard
* Mon Jan 11 2016 joop.boonen@opensuse.org
- Added ip6tables support handles via init and service files
* Fri Oct 16 2015 joop.boonen@opensuse.org
- Corrected a iptables error, that prevented sshguard
  from functioning correctly
* Thu Oct 15 2015 joop.boonen@opensuse.org
- Moved blacklist.db to /var/lib/sshguard/db/blacklist.db analog
  most SUSE packages
* Thu Oct 15 2015 joop.boonen@opensuse.org
- Corrected the blacklist as it's auto generated
- Improved sysconfig
* Wed Oct 14 2015 joop.boonen@opensuse.org
- Build version 1.6.2
  + Make '-w' option backwards-compatible for iptables (James Harris)
  + Remove support for ip6fw and 'ipfw-range' option
  + Rewrite ipfw backend using command framework
- The white and black list now initially reside in files
  /etc/sshguard/whitelist|blacklist
* Mon Sep 28 2015 joop.boonen@opensuse.org
- Build version 1.6.1
- Added sshguard-gcc5.patch so it also builds via gcc5
- Created a sshguard.service file so it'll run on systemd
  systems
* Wed Mar 27 2013 joop.boonen@opensuse.org
- Reformated the spec file to the openSUSE standard
  so it can be submitted to Factory
* Sat Feb 19 2011 lars@linux-schulserver.de
- update to 1.5:
  + logsucker: sshguard polls multiple log files at once
  + recognize syslog's "last message repeated N times" contextually
    and per-source
  + attackers now gauged with attack *dangerousness* instead of
    count (adjust your -a !)
  + improve IPv6 support
  + add detection for: Exim, vsftpd, Sendmail, Cucipop
  + improve logging granularity and descriptiveness
  + add -i command line option for saving PID file as an aid for
    startup scripts
  + update some attack signatures
- cleanup specfile via spec-cleaner
* Wed Dec  1 2010 wr@rosenauer.org
- fix typo in macro
- revert a bit of cleanup to make it backwards compatible
  (%%_initddir)
* Tue Nov  2 2010 prusnak@opensuse.org
- cleanup spec file
* Wed Sep 29 2010 wr@rosenauer.org
- update to version 1.5rc4
* Sun Apr  4 2010 wr@rosenauer.org
- update to version 1.5rc1
* Thu Feb 11 2010 wr@rosenauer.org
- added init script and sysconfig
* Wed Feb 10 2010 wr@rosenauer.org
- initial openSUSE package
